@@ -955,8 +955,8 @@ class Settings:
             except Exception:
                 pass
 
-        png = os.path.join(data.RESOURCE_PATH, "rummage_hires.png")
-        icon = os.path.join(data.RESOURCE_PATH, "rummage_tray.ico")
+        png = os.path.join(data.RESOURCE_PATH, "rummage_1024.png")
+        icon = os.path.join(data.RESOURCE_PATH, "rummage.ico")
         icns = os.path.join(data.RESOURCE_PATH, "rummage.icns")
 
         if not os.path.exists(png):
